"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _csvString = require("csv-string");

var CsvHandler = {
  /**
   * Returns the raw CSV content (as array of arrays) from the CSV content string.
   * @param {string} csvContent - the content of the CSV file as string
   * @returns {Array} an array of arrays containing each lines / columns of the CSV content
   */
  parseCsvFileContent: function parseCsvFileContent(csvContent) {
    return (0, _csvString.parse)(csvContent);
  },

  /**
   * Reads a CSV file and returns the content of the file as string
   * @param {Event} fileChangeEvent - the onChange event of the <input type="file">
   * @returns {Promise} a promise that resolves with the content of the selected file as string 
   * or rejects with an error, if the file cannot be read.
   */
  parseCsvFile: function parseCsvFile(file) {
    var _this = this;

    var reader = new FileReader();
    return new Promise(function (resolve, reject) {
      reader.onload = function () {
        return function (loadEvent) {
          var csvContent = loadEvent.target.result;
          resolve(_this.parseCsvFileContent(csvContent));
        };
      }(file);

      reader.onerror = function (errorEvent) {
        reject(errorEvent);
      };

      reader.readAsText(file);
    });
  }
};
var _default = CsvHandler;
exports["default"] = _default;